@@ -168,7 +168,7 @@ static void on_delete_template (GtkWidget *w, gcpTemplateToolDlg *dlg)
 	dlg->OnDeleteTemplate ();
 }
 
-gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): gcpDialog(App, PKGDATADIR"/ui/templates.glade", "templates")
+gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): gcpDialog(App, GLADEDIR"/templates.glade", "templates")
 {
 	tree = (gcpTemplateTree*) App->GetTool ("TemplateTree");
 	if (!tree) {delete this; return;}
@@ -308,7 +308,7 @@ void gcpTemplateToolDlg::SetTemplate (gcpTemplate* t)
 	}
 }
 
-gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App): gcpDialog(App, PKGDATADIR"/ui/new-template.glade", "new_template")
+gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App): gcpDialog(App, GLADEDIR"/new-template.glade", "new_template")
 {
 	pDoc = new gcpDocument(m_App, true);
 	pDoc->SetEditable (false);
